pub enum InvalidMoveType<V> {
InvalidCar,
InvalidDirection,
InvalidFinalPosition,
Intersects(Position<V>, NonZeroUsize),
}Expand description
The type of invalid move that was observed in an InvalidMoveError.
Variants
InvalidCar
The car that was designated to be moved didn’t exist.
InvalidDirection
The direction that was used isn’t valid for the provided car.
InvalidFinalPosition
The final position of the car is out of bounds.
Intersects(Position<V>, NonZeroUsize)
After moving the car, the car would intersect another with the provided index at the provided position.