pub enum InvalidStateType {
InvalidPosition(NonZeroUsize),
Overlap(NonZeroUsize, NonZeroUsize),
}Expand description
A type of invalid state, associated with an InvalidStateError.
Variants
InvalidPosition(NonZeroUsize)
The car with the provided index is in an invalid position.
Overlap(NonZeroUsize, NonZeroUsize)
The cars with the provided indices overlap.