Position

Struct Position 

pub struct Position<V> { /* private fields */ }
A position in the board (eff., a coordinate pair).

Implementations

Source

impl<V> Position<V>

pub fn row(&self) -> &V

The row of the position.

pub fn column(&self) -> &V

The column of the position.

Source

impl<V> Position<V>
where V: BoardValue,

pub fn as_index(&self, dim: &Dimensions<V>) -> Option<usize>

The position encoded as an index into an board with the provided dimensions.

Source

impl<V> Position<V>
where Self: CheckedAdd<Output = Self> + CheckedSub<Output = Self>, V: BoardValue,

pub fn shift(&self, dir: Direction, by: V) -> Option<Self>

Get the position by units away from this position in the provided direction dir, or None if the position would be out of bounds.