State

Struct State 

pub struct State<V> { /* private fields */ }
A state of the game. This is guaranteed to be a valid state as long as it is constructed with State::empty and manipulated with via Board operations.

Implementations

Source

impl<V> State<V>

pub fn dimensions(&self) -> &Dimensions<V>

The dimensions of this state.

pub fn cars(&self) -> &[(Position<V>, Car<V>)]

The cars contained within this state.

Source

impl<V> State<V>

pub fn empty<D: TryInto<Dimensions<V>>>(dim: D) -> Result<Self, D::Error>

Produce an empty state (i.e., one with no cars) with the provided dimensions.

Source

impl<V> State<V>
where V: BoardValue,

pub fn board(&self) -> Result<Board<&Self, V>, InvalidStateError<V>>

An immutable representation of the current board, or an error if this state is invalid.

pub fn board_mut(&mut self) -> Result<Board<&mut Self, V>, InvalidStateError<V>>

A mutable representation of the current board, or an error if this state is invalid.