pub struct State<V> { /* private fields */ }Expand description
A state of the game. This is guaranteed to be a valid state as long as it is constructed with
State::empty and manipulated with via Board operations.
Implementations
Sourceimpl<V> State<V>
impl<V> State<V>
Sourcepub fn dimensions(&self) -> &Dimensions<V>
pub fn dimensions(&self) -> &Dimensions<V>
The dimensions of this state.
Sourceimpl<V> State<V>where
V: BoardValue,
impl<V> State<V>where
V: BoardValue,
Sourcepub fn board(&self) -> Result<Board<&Self, V>, InvalidStateError<V>>
pub fn board(&self) -> Result<Board<&Self, V>, InvalidStateError<V>>
An immutable representation of the current board, or an error if this state is invalid.
Sourcepub fn board_mut(&mut self) -> Result<Board<&mut Self, V>, InvalidStateError<V>>
pub fn board_mut(&mut self) -> Result<Board<&mut Self, V>, InvalidStateError<V>>
A mutable representation of the current board, or an error if this state is invalid.